@@ -111,6 +111,8 @@ class AsymmetricAES(object):
 		memory=False,
 	):
 		self.rsa = rsa.RSA(public_key=public_key, private_key=private_key, passphrase=passphrase, memory=memory)
+
+	# functions.
 	def generate_keys(self):
 		return self.rsa.generate_keys()
 	def edit_passphrase(self, passphrase=None):
@@ -182,7 +184,7 @@ class AsymmetricAES(object):
 		#
 	def encrypt_file(self, input=None, output=None, remove=False, base64_encoding=False):
 		input = Formats.denitialize(input)
-		ouput = Formats.denitialize(ouput)
+		output = Formats.denitialize(output)
 
 		# check params.
 		response = r3sponse.check_parameters({
@@ -212,7 +214,7 @@ class AsymmetricAES(object):
 		#
 	def decrypt_file(self, input=None, output=None, remove=False, base64_encoding=False):
 		input = Formats.denitialize(input)
-		ouput = Formats.denitialize(ouput)
+		output = Formats.denitialize(output)
 
 		# check params.
 		response = r3sponse.check_parameters({
@@ -242,7 +244,7 @@ class AsymmetricAES(object):
 		#
 	def encrypt_directory(self, input=None, output=None, remove=False):
 		input = Formats.denitialize(input)
-		ouput = Formats.denitialize(ouput)
+		output = Formats.denitialize(output)
 
 		# checks.
 		file_path = FilePath(input)
@@ -285,7 +287,7 @@ class AsymmetricAES(object):
 		#
 	def decrypt_directory(self, input=None, output=None, remove=False):
 		input = Formats.denitialize(input)
-		ouput = Formats.denitialize(ouput)
+		output = Formats.denitialize(output)
 		
 		# checks.
 		file_path = FilePath(input)
@@ -344,6 +346,17 @@ class AsymmetricAES(object):
 
 		#
 
+	# properties.
+	@property
+	def activated(self):
+		return self.rsa.activated
+	@property
+	def public_key_activated(self):
+		return self.rsa.public_key_activated
+	@property
+	def private_key_activated(self):
+		return self.rsa.private_key_activated
+
 # the aes database object class.
 class Database(object):
 	def __init__(self,
@@ -368,30 +381,27 @@ class Database(object):
 			self.fp.ownership.set(owner=syst3m.defaults.vars.owner)
 			self.fp.permission.set(permission=770)
 
-		# variables.
-		self.activated = False
-
 		#
-	def activate(self):
 
-		# check sample.
+	# functions.
+	def activate(self, 
+		# the key;s passphrase (optional).
+		passphrase=None,
+	):
+
+		# passphrase.
+		if passphrase != None:
+			self.aes.rsa.passphrase = passphrase
+			
+		# check root.
 		if not Files.exists(f"{self.path}"):
 			return r3sponse.error(f"Encrypted database root [{self.path}] does not exist.")
-		if not Files.exists(f"{self.path}.passphrase"):
-			response = self.aes.encrypt(self.aes.rsa.passphrase)
-			if not response.success: return response
-			try: utils.__save_bytes__(f"{self.path}.passphrase", response.encrypted)
-			except: return r3sponse.error(f"Failed to write out encrypted passphrase [{self.path}.passphrase]")
-		else:
-			try: passphrase = utils.__load_bytes__(f"{self.path}.passphrase")
-			except: return r3sponse.error(f"Failed to load encrypted passphrase [{self.path}.passphrase]")
-			response = self.aes.decrypt(passphrase)
-			if not response.success: return response
-			if response.decrypted.decode().replace("\n","") != self.aes.rsa.passphrase.replace("\n",""):
-				return r3sponse.error("Specified an incorrect passphrase.")
+
+		# activate keys.
+		response = self.aes.load_keys()
+		if not response.success: return response
 
 		# success.
-		self.activated = True
 		return r3sponse.success(f"Successfully activated encrypted database [{self.path}].")
 
 		#
@@ -482,6 +492,18 @@ class Database(object):
 		if not response.success: return response
 		return r3sponse.success(f"Successfully saved content {path}.")
 
+	# properties.
+	@property
+	def activated(self):
+		return self.aes.activated
+	@property
+	def public_key_activated(self):
+		return self.aes.public_key_activated
+	@property
+	def private_key_activated(self):
+		return self.aes.private_key_activated
+	
+
 	# a file data object
 	class File(File):
 		def __init__(self,
