@@ -333,4 +333,4 @@ class Date(object):
 		#
 	def convert(self, string, input="%d-%m-%y %H:%M", output="%Y%m%d"):
 		string = datetime.strptime(string, input)
-		return string.strftime(ouput)
+		return string.strftime(output)
